@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package asn1
@@ -27,7 +22,7 @@ import (
 )
 
 // Read reads the next glow data block of the appropriate type, it checks the glow tag against the provided compare
-// function and if they match it reads the glow data block and returns it as its own decoded, original decoder might
+// function and if they match it reads the glow data block and returns it as it's own decoded, original decoder might
 // have more data left, THIS DOES NOT READ ALL THE DATA.
 // If no length byte is found in data returns ALL remaining bytes.
 // Returns True if next element length is unknown.
@@ -92,7 +87,7 @@ func (c *Decoder) readLength() (int, int, error) {
 		offset = 1
 	)
 
-	for range int(lenB) {
+	for i := 0; i < int(lenB); i++ {
 		val, err := c.data.ReadByte()
 		if err != nil {
 			return 0, 0, errs.Wrap(err, "incorrect additional length bytes")
@@ -121,7 +116,7 @@ func (c *Decoder) ReadEnd() (bool, error) {
 		return false, nil
 	}
 
-	for range closingOffset {
+	for i := 0; i < closingOffset; i++ {
 		_, err := c.data.ReadByte()
 		if err != nil {
 			return false, errs.Wrapf(err, "failed to read end bytes")
